summaryrefslogtreecommitdiffstats
path: root/content/common
diff options
context:
space:
mode:
authordbeam@chromium.org <dbeam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-30 21:43:00 +0000
committerdbeam@chromium.org <dbeam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2013-12-30 21:43:00 +0000
commitf527d9cdabd11282598dc769fa32ed9490c877d9 (patch)
tree3387e648f4cf2b95402a68fef36f60d1738752ff /content/common
parent42303816401b4b75fb221c6e59d423fd2ec32f5d (diff)
downloadchromium_src-f527d9cdabd11282598dc769fa32ed9490c877d9.zip
chromium_src-f527d9cdabd11282598dc769fa32ed9490c877d9.tar.gz
chromium_src-f527d9cdabd11282598dc769fa32ed9490c877d9.tar.bz2
Remove 'using base::string16;' from base/strings/string16.h and remove temporary
PRESUBMIT.py _CheckForString16(). R=brettw@chromium.org, maruel@chromium.org TBR=sky@chromium.org, tsepez@chromium.org BUG=329295 Review URL: https://codereview.chromium.org/93903011 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@242733 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'content/common')
-rw-r--r--content/common/view_messages.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/content/common/view_messages.h b/content/common/view_messages.h
index 791920a..561928f 100644
--- a/content/common/view_messages.h
+++ b/content/common/view_messages.h
@@ -1953,7 +1953,8 @@ IPC_MESSAGE_ROUTED0(ViewHostMsg_SelectRange_ACK)
IPC_MESSAGE_ROUTED0(ViewHostMsg_MoveCaret_ACK)
// Notification that the text selection has changed.
// Note: The secound parameter is the character based offset of the string16
// text in the document.
IPC_MESSAGE_ROUTED3(ViewHostMsg_SelectionChanged,
base::string16 /* text covers the selection range */,
@@ -2308,8 +2309,7 @@ IPC_MESSAGE_ROUTED1(ViewHostMsg_SetNeedsBeginFrame,
// instead of encoding the data as a string which is not allowed normally. Since
// ths is only used in Android WebView, it's allowed temporarily.
// http://crbug.com/330872
-IPC_MESSAGE_ROUTED1(ViewHostMsg_SmartClipDataExtracted,
- string16)
+IPC_MESSAGE_ROUTED1(ViewHostMsg_SmartClipDataExtracted, base::string16)
#elif defined(OS_MACOSX)
// Request that the browser load a font into shared memory for us.
@@ -1953,7 +1953,8 @@ IPC_MESSAGE_ROUTED0(ViewHostMsg_SelectRange_ACK)
IPC_MESSAGE_ROUTED0(ViewHostMsg_MoveCaret_ACK)
// Notification that the text selection has changed.
-// Note: The secound parameter is the character based offset of the string16
+// Note: The secound parameter is the character based offset of the
+// base::string16
// text in the document.
IPC_MESSAGE_ROUTED3(ViewHostMsg_SelectionChanged,